from skeleton.settings import *


FOUNDRY['layers'] = ('smart', 'basic')
SITE_ID = 4
